use crate::tcp_relay_client::client_config::ClientConfig;
use crate::test::pki::Pki;
use crate::test::{get_port_number, PortsAllocation, LOCALHOST_IP};

const VALID_TOKEN: &str = "AvalidTOKEN";

fn port(index: u16) -> u16 {
    get_port_number(PortsAllocation::TestsWithoutPortOpened, index)
}

#[tokio::test()]
async fn invalid_file_type() {
    let _ = env_logger::builder().is_test(true).try_init();

    let pki = Pki::load();

    crate::tcp_relay_client::run_app(ClientConfig {
        token: Some(VALID_TOKEN.to_string()),
        relay_url: format!("https://{}:{}", LOCALHOST_IP, port(0)),
        listen_address: LOCALHOST_IP.to_string(),
        root_certificate: Some(pki.expired_client_key.file_path()),
        ..Default::default()
    })
    .await
    .unwrap_err();
}

#[tokio::test()]
async fn non_existing_file() {
    let _ = env_logger::builder().is_test(true).try_init();

    crate::tcp_relay_client::run_app(ClientConfig {
        token: Some(VALID_TOKEN.to_string()),
        relay_url: format!("https://{}:{}", LOCALHOST_IP, port(0)),
        listen_address: LOCALHOST_IP.to_string(),
        root_certificate: Some("/bad/path/to/file".to_string()),
        ..Default::default()
    })
    .await
    .unwrap_err();
}
